#include <QtGui/QApplication>
#include "mainwindow.h"


int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
    QCoreApplication::setApplicationName("TPlayer");
    QCoreApplication::setApplicationVersion("0.0.2beta");
    MainWindow w;






#ifndef Q_WS_MAEMO_5
    w.show();
    w.resize(800,460);
    w.move(0,0);
#else
    w.showFullScreen();
#endif
//
    return a.exec();
}
